=======
Credits
=======

Development Lead
----------------

* Ardy Dedase <ardy.dedase@skyscanner.net> 

Contributors
------------

* Denis Dudnik <deniska.dudnik@gmail.com>
* Kelvin Tay <kelvintaywl@gmail.com>
